@@ -255,7 +255,35 @@ get_provider_node (GtkSourceCompletionModel    *model,
 	return NULL;
 }
 
-/* Remove providers or proposals */
+static gboolean
+get_last_iter (GtkSourceCompletionModel *model,
+	       GtkTreeIter              *iter)
+{
+	GList *last_provider;
+	ProviderInfo *provider_info;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
+	g_return_val_if_fail (iter != NULL, FALSE);
+
+	last_provider = g_list_last (model->priv->providers);
+
+	if (last_provider == NULL)
+	{
+		return FALSE;
+	}
+
+	provider_info = last_provider->data;
+
+	iter->user_data = provider_info->proposals->tail;
+	g_assert (iter->user_data != NULL);
+
+	if (!provider_info->visible)
+	{
+		return gtk_source_completion_model_iter_previous (model, iter);
+	}
+
+	return TRUE;
+}
 
 static void
 proposal_info_free (gpointer data)
@@ -296,8 +324,6 @@ provider_info_free (gpointer data)
 	g_slice_free (ProviderInfo, data);
 }
 
-/* Show/hide header */
-
 static void
 add_header (GList *provider_node)
 {
@@ -825,69 +851,7 @@ gtk_source_completion_model_add_proposals (GtkSourceCompletionModel    *model,
 	g_list_foreach (proposals, (GFunc)add_proposal, provider_node);
 }
 
-/* Get/set visible providers */
-
-static void
-show_provider (GtkSourceCompletionModel *model,
-	       ProviderInfo             *provider_info)
-{
-	GtkTreePath *path;
-	GList *l;
-
-	path = get_proposal_path (model, provider_info->proposals->head);
-
-	for (l = provider_info->proposals->head; l != NULL; l = l->next)
-	{
-		GtkTreeIter iter;
-		iter.user_data = l;
-
-		gtk_tree_model_row_inserted (GTK_TREE_MODEL (model), path, &iter);
-
-		gtk_tree_path_next (path);
-	}
-
-	gtk_tree_path_free (path);
-}
-
-static void
-hide_provider (GtkSourceCompletionModel *model,
-	       ProviderInfo             *provider_info)
-{
-	GtkTreePath *path;
-	gint i;
-
-	path = get_proposal_path (model, provider_info->proposals->head);
-
-	for (i = 0; i < provider_info->proposals->length; i++)
-	{
-		gtk_tree_model_row_deleted (GTK_TREE_MODEL (model), path);
-	}
-
-	gtk_tree_path_free (path);
-}
-
-static void
-update_provider_visibility (GtkSourceCompletionModel *model,
-			    ProviderInfo             *provider_info)
-{
-	gboolean new_visible = is_provider_visible (model, provider_info->completion_provider);
-
-	if (new_visible == provider_info->visible)
-	{
-		return;
-	}
-
-	if (new_visible)
-	{
-		provider_info->visible = TRUE;
-		show_provider (model, provider_info);
-	}
-	else
-	{
-		hide_provider (model, provider_info);
-		provider_info->visible = FALSE;
-	}
-}
+/* Other public functions */
 
 void
 gtk_source_completion_model_set_visible_providers (GtkSourceCompletionModel *model,
@@ -911,7 +875,7 @@ gtk_source_completion_model_set_visible_providers (GtkSourceCompletionModel *mod
 	for (l = model->priv->providers; l != NULL; l = l->next)
 	{
 		ProviderInfo *provider_info = l->data;
-		update_provider_visibility (model, provider_info);
+		provider_info->visible = is_provider_visible (model, provider_info->completion_provider);
 	}
 }
 
@@ -923,8 +887,6 @@ gtk_source_completion_model_get_visible_providers (GtkSourceCompletionModel *mod
 	return model->priv->visible_providers;
 }
 
-/* Other public functions */
-
 /* If @only_visible is %TRUE, only the visible providers are taken into account. */
 gboolean
 gtk_source_completion_model_is_empty (GtkSourceCompletionModel *model,
@@ -950,38 +912,6 @@ gtk_source_completion_model_is_empty (GtkSourceCompletionModel *model,
 	return TRUE;
 }
 
-/* Returns the number of proposals. The header is not taken into account. */
-guint
-gtk_source_completion_model_n_proposals (GtkSourceCompletionModel    *model,
-                                         GtkSourceCompletionProvider *provider)
-{
-	GList *provider_node;
-	ProviderInfo *provider_info;
-	guint nb_items;
-
-	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), 0);
-	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_PROVIDER (provider), 0);
-
-	provider_node = get_provider_node (model, provider);
-
-	if (provider_node == NULL)
-	{
-		return 0;
-	}
-
-	provider_info = provider_node->data;
-	nb_items = provider_info->proposals->length;
-
-	if (model->priv->show_headers)
-	{
-		return nb_items - 1;
-	}
-	else
-	{
-		return nb_items;
-	}
-}
-
 void
 gtk_source_completion_model_set_show_headers (GtkSourceCompletionModel *model,
                                               gboolean                  show_headers)
@@ -1077,36 +1007,6 @@ gtk_source_completion_model_iter_previous (GtkSourceCompletionModel *model,
 	return TRUE;
 }
 
-gboolean
-gtk_source_completion_model_iter_last (GtkSourceCompletionModel *model,
-                                       GtkTreeIter              *iter)
-{
-	GList *last_provider;
-	ProviderInfo *provider_info;
-
-	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
-	g_return_val_if_fail (iter != NULL, FALSE);
-
-	last_provider = g_list_last (model->priv->providers);
-
-	if (last_provider == NULL)
-	{
-		return FALSE;
-	}
-
-	provider_info = last_provider->data;
-
-	iter->user_data = provider_info->proposals->tail;
-	g_assert (iter->user_data != NULL);
-
-	if (!provider_info->visible)
-	{
-		return gtk_source_completion_model_iter_previous (model, iter);
-	}
-
-	return TRUE;
-}
-
 /* Get all the providers (visible and hidden), sorted by priority in descending
  * order (the highest priority first).
  * Free the return value with g_list_free().
@@ -1128,6 +1028,100 @@ gtk_source_completion_model_get_providers (GtkSourceCompletionModel *model)
 	return g_list_reverse (ret);
 }
 
+/* Get the first proposal. Headers are skipped.
+ * Returns TRUE on success.
+ */
+gboolean
+gtk_source_completion_model_first_proposal (GtkSourceCompletionModel *model,
+					    GtkTreeIter              *iter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
+	g_return_val_if_fail (iter != NULL, FALSE);
+
+	if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), iter))
+	{
+		return FALSE;
+	}
+
+	while (gtk_source_completion_model_iter_is_header (model, iter))
+	{
+		if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), iter))
+		{
+			return FALSE;
+		}
+	}
+
+	return TRUE;
+}
+
+/* Get the last proposal. Headers are skipped.
+ * Returns TRUE on success.
+ */
+gboolean
+gtk_source_completion_model_last_proposal (GtkSourceCompletionModel *model,
+					   GtkTreeIter              *iter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
+	g_return_val_if_fail (iter != NULL, FALSE);
+
+	if (!get_last_iter (model, iter))
+	{
+		return FALSE;
+	}
+
+	while (gtk_source_completion_model_iter_is_header (model, iter))
+	{
+		if (!gtk_source_completion_model_iter_previous (model, iter))
+		{
+			return FALSE;
+		}
+	}
+
+	return TRUE;
+}
+
+/* Get the next proposal. Headers are skipped.
+ * Returns TRUE on success.
+ */
+gboolean
+gtk_source_completion_model_next_proposal (GtkSourceCompletionModel *model,
+					   GtkTreeIter              *iter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
+	g_return_val_if_fail (iter != NULL && iter->user_data != NULL, FALSE);
+
+	do
+	{
+		if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), iter))
+		{
+			return FALSE;
+		}
+	} while (gtk_source_completion_model_iter_is_header (model, iter));
+
+	return TRUE;
+}
+
+/* Get the previous proposal. Headers are skipped.
+ * Returns TRUE on success.
+ */
+gboolean
+gtk_source_completion_model_previous_proposal (GtkSourceCompletionModel *model,
+					       GtkTreeIter              *iter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
+	g_return_val_if_fail (iter != NULL && iter->user_data != NULL, FALSE);
+
+	do
+	{
+		if (!gtk_source_completion_model_iter_previous (model, iter))
+		{
+			return FALSE;
+		}
+	} while (gtk_source_completion_model_iter_is_header (model, iter));
+
+	return TRUE;
+}
+
 gboolean
 gtk_source_completion_model_iter_equal (GtkSourceCompletionModel *model,
                                         GtkTreeIter              *iter1,
