@@ -28,27 +28,13 @@
 G_BEGIN_DECLS
 
 G_GNUC_INTERNAL
-gboolean	 gtk_source_completion_utils_is_separator		(gunichar         ch);
-
-G_GNUC_INTERNAL
-gchar		*gtk_source_completion_utils_get_word_iter		(GtkSourceBuffer *source_buffer,
-									 GtkTextIter     *current,
+void		 gtk_source_completion_utils_get_word_iter		(GtkTextBuffer   *buffer,
 									 GtkTextIter     *start_word,
 									 GtkTextIter     *end_word);
 
 G_GNUC_INTERNAL
-gchar		*gtk_source_completion_utils_get_word			(GtkSourceBuffer *text_view);
-
-G_GNUC_INTERNAL
-void		 gtk_source_completion_utils_replace_word		(GtkSourceBuffer *source_buffer,
-									 GtkTextIter     *iter,
-									 const gchar     *text,
-									 gint             len);
-
-G_GNUC_INTERNAL
-void		 gtk_source_completion_utils_replace_current_word	(GtkSourceBuffer *source_buffer,
-									 const gchar     *text,
-									 gint             len);
+void		 gtk_source_completion_utils_replace_current_word	(GtkTextBuffer   *buffer,
+									 const gchar     *text);
 
 G_GNUC_INTERNAL
 void		 gtk_source_completion_utils_move_to_iter		(GtkWindow       *window,
