@@ -30,12 +30,9 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourcelanguage.h>
-#include <gtksourceview/gtksourcelanguagemanager.h>
-#include <gtksourceview/gtksourcestyleschememanager.h>
-#include <gtksourceview/gtksourceprintcompositor.h>
-#include <gtksourceview/gtksourceview-typebuiltins.h>
+#include <gtksourceview/gtksource.h>
+#include "gtksourceview/gtksourceview-typebuiltins.h"
+
 #ifdef TEST_XML_MEM
 #include <libxml/xmlreader.h>
 #endif
@@ -1621,7 +1618,6 @@ init_mem_stuff (void)
 		};
 
 		g_mem_set_vtable (&mem_table);
-		g_slice_set_config (G_SLICE_CONFIG_ALWAYS_MALLOC, TRUE);
 	}
 }
 
